@@ -150,13 +150,15 @@ class EventletEvent(object):
     """
     def __init__(self, *args, **kwargs):
         super(EventletEvent, self).__init__()
+        self._set = False
         self.clear()
 
     def clear(self):
         old_event = getattr(self, "_event", None)
+        was_set = self._set
         self._set = False
         self._event = _eventlet.event.Event()
-        if old_event is not None:
+        if old_event is not None and not was_set:
             old_event.send(True)
 
     def is_set(self):
@@ -165,11 +167,9 @@ class EventletEvent(object):
     isSet = is_set
 
     def set(self):
-        if self._set:
-            self._event.reset()
-
-        self._set = True
-        self._event.send(True)
+        if not self._set:
+            self._set = True
+            self._event.send(True)
 
     def wait(self, timeout=None):
         with timeutils.StopWatch(timeout) as sw:
