@@ -15,6 +15,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import collections
 import copy
 import math
 
@@ -187,6 +188,7 @@ class StringToBytesTest(test_base.BaseTestCase):
     _unit_system = [
         ('si', dict(unit_system='SI')),
         ('iec', dict(unit_system='IEC')),
+        ('mixed', dict(unit_system='mixed')),
         ('invalid_unit_system', dict(unit_system='KKK', assert_error=True)),
     ]
 
@@ -259,6 +261,14 @@ class StringToBytesTest(test_base.BaseTestCase):
                     res = getattr(units, unit_prefix)
                 else:
                     res = getattr(units, '%si' % unit_prefix)
+            elif unit_system == 'mixed':
+                # Note: this will return 'i' units as power-of-two,
+                # and other units as power-of-ten.  Additionally, for
+                # compatability a "K" is interpreted as "k" in mixed
+                # mode
+                if unit_prefix == 'K':
+                    unit_prefix = 'k'
+                res = getattr(units, unit_prefix)
             return res
 
         text = ''.join([self.sign, self.magnitude, self.unit_prefix,
@@ -604,6 +614,31 @@ class MaskPasswordTestCase(test_base.BaseTestCase):
         self.assertEqual(expected, strutils.mask_password(payload))
 
 
+class TestMapping(collections.Mapping):
+    """Test class for non-dict mappings"""
+    def __init__(self):
+        super(TestMapping, self).__init__()
+        self.data = {'password': 'shhh',
+                     'foo': 'bar',
+                     }
+
+    def __getitem__(self, key):
+        return self.data[key]
+
+    def __iter__(self):
+        return self.data.__iter__()
+
+    def __len__(self):
+        return len(self.data)
+
+
+class NestedMapping(TestMapping):
+    """Test class that contains an instance of TestMapping"""
+    def __init__(self):
+        super(NestedMapping, self).__init__()
+        self.data = {'nested': TestMapping()}
+
+
 class MaskDictionaryPasswordTestCase(test_base.BaseTestCase):
 
     def test_dictionary(self):
@@ -651,6 +686,13 @@ class MaskDictionaryPasswordTestCase(test_base.BaseTestCase):
         self.assertEqual(expected,
                          strutils.mask_dict_password(payload))
 
+    def test_do_an_int(self):
+        payload = {}
+        payload[1] = 2
+        expected = payload.copy()
+        self.assertEqual(expected,
+                         strutils.mask_dict_password(payload))
+
     def test_mask_values(self):
         payload = {'somekey': 'test = cmd --password my\xe9\x80\x80pass'}
         expected = {'somekey': 'test = cmd --password ***'}
@@ -680,6 +722,21 @@ class MaskDictionaryPasswordTestCase(test_base.BaseTestCase):
         strutils.mask_dict_password(payload)
         self.assertEqual(pristine, payload)
 
+    def test_non_dict(self):
+        expected = {'password': '***',
+                    'foo': 'bar',
+                    }
+        payload = TestMapping()
+        self.assertEqual(expected, strutils.mask_dict_password(payload))
+
+    def test_nested_non_dict(self):
+        expected = {'nested': {'password': '***',
+                               'foo': 'bar',
+                               }
+                    }
+        payload = NestedMapping()
+        self.assertEqual(expected, strutils.mask_dict_password(payload))
+
 
 class IsIntLikeTestCase(test_base.BaseTestCase):
     def test_is_int_like_true(self):
